import { Command } from 'ckeditor5/src/core';

export default class LoremIpsumCommand extends Command {
  execute({ numParagraphs = 1 } = {}) {
    const editor = this.editor;
    const model = editor.model;
    const loremText = this._generateLoremIpsum(numParagraphs);

    model.change(writer => {
      let insertPosition = model.document.selection.getFirstPosition();

      if (!insertPosition) {
        insertPosition = model.document.getRoot().end;
      }

      const paragraphs = loremText.split('\n\n');
      let lastParagraphElement = null;

      paragraphs.forEach(paragraph => {
        const paragraphElement = writer.createElement('paragraph');
        const textNode = writer.createText(paragraph);
        writer.append(textNode, paragraphElement);
        model.insertContent(paragraphElement, insertPosition);
        insertPosition = writer.createPositionAfter(paragraphElement);
        lastParagraphElement = paragraphElement;
      });

      // Set the selection to the end of the last paragraph
      if (lastParagraphElement) {
        const endPosition = writer.createPositionAfter(lastParagraphElement);
        writer.setSelection(endPosition);
      }

    });
  }

  _generateLoremIpsum(numParagraphs) {
    const loremWords = [
      'Lorem', 'ipsum', 'dolor', 'sit', 'amet', 'consectetur',
      'adipiscing', 'elit', 'sed', 'do', 'eiusmod', 'tempor',
      'incididunt', 'ut', 'labore', 'et', 'dolore', 'magna',
      'aliqua', 'Ut', 'enim', 'ad', 'minim', 'veniam', 'quis',
      'nostrud', 'exercitation', 'ullamco', 'laboris', 'nisi',
      'ut', 'aliquip', 'ex', 'ea', 'commodo', 'consequat',
      'Duis', 'aute', 'irure', 'dolor', 'in', 'reprehenderit',
      'in', 'voluptate', 'velit', 'esse', 'cillum', 'dolore',
      'eu', 'fugiat', 'nulla', 'pariatur', 'Excepteur', 'sint',
      'occaecat', 'cupidatat', 'non', 'proident', 'sunt', 'in',
      'culpa', 'qui', 'officia', 'deserunt', 'mollit', 'anim',
      'id', 'est', 'laborum', 'tempor', 'vitae', 'exercitationem',
      'magnam', 'cursus', 'at', 'praesent', 'faucibus', 'ultricies',
      'lectus', 'integer', 'ipsum', 'vitae', 'semper', 'pellentesque',
      'magna', 'sit', 'dui', 'facilisi', 'velit', 'eros', 'scelerisque'
    ];

    let text = '';
    for (let i = 0; i < numParagraphs; i++) {
      text += this._generateRandomParagraph(loremWords) + '\n\n';
    }
    return text.trim();
  }

  _generateRandomParagraph(words) {
    const sentenceLength = this._getRandomNumber(50, 75);
    const randomWords = Array.from({ length: sentenceLength }, () => words[Math.floor(Math.random() * words.length)]);
    const sentence = randomWords.join(' ').trim();
    return sentence.charAt(0).toUpperCase() + sentence.slice(1) + '.';
  }

  _getRandomNumber(min, max) {
    return Math.floor(Math.random() * (max - min + 1)) + min;
  }
}
