import { Plugin } from 'ckeditor5/src/core';
import { createDropdown, addListToDropdown } from 'ckeditor5/src/ui';
import { Collection } from 'ckeditor5/src/utils';

export default class LoremIpsumUI extends Plugin {
  static get pluginName() {
    return 'LoremIpsumUI';
  }

  init() {
    const editor = this.editor;

    // Add the toolbar item.
    editor.ui.componentFactory.add('loremIpsum', locale => {
      const dropdownView = createDropdown(locale);

      // Configure dropdown button
      const buttonView = dropdownView.buttonView;
      buttonView.set({
        label: 'Lorem Ipsum',
        withText: true,
        tooltip: true,
      });

      // Create items collection
      const items = new Collection();
      const options = [1, 2, 3, 5, 7];

      options.forEach(num => {
        items.add({
          type: 'button',
          model: {
            label: `${num} paragraph${num > 1 ? 's' : ''}`,
            withText: true,
            numParagraphs: num,
          }
        });
      });

      // Add items to dropdown
      addListToDropdown(dropdownView, items);

      // Handle dropdown item selection
      dropdownView.on('execute', evt => {
        const numParagraphs = evt.source.numParagraphs;
        editor.execute('loremIpsum', { numParagraphs });
        // Focus back to the editor
        editor.editing.view.focus();
      });

      return dropdownView;
    });
  }
}
